@@ -1,37 +1,40 @@
 use strict;
 use warnings;
+use lib '../lib/blib';
 {
-    use Alien::FLTK;
+    use Alien::FLTK2;
     use ExtUtils::CBuilder;
-    my $AF  = Alien::FLTK->new();
-    my $CC  = ExtUtils::CBuilder->new();
-    my $SRC = 'hello_world.cxx';
-    open(my $FH, '>', $SRC) || die '...';
+    my $AF     = Alien::FLTK->new();
+    my $CC     = ExtUtils::CBuilder->new();
+    my $source = 'hello_world.cxx';
+    open(my $FH, '>', $source) || die '...';
     syswrite($FH, <<'') || die '...'; close $FH;
-      #include <FL/Fl.H>
-      #include <FL/Fl_Window.H>
-      #include <FL/Fl_Box.H>
+      #include <fltk/Window.h>
+      #include <fltk/Widget.h>
+      #include <fltk/run.h>
+      using namespace fltk;
       int main(int argc, char **argv) {
-        Fl_Window *window = new Fl_Window(300,180);
-        Fl_Box *box = new Fl_Box(FL_UP_BOX, 20, 40, 260, 100, "Hello, World!");
-        box->labelfont(FL_BOLD + FL_ITALIC);
+        Window *window = new Window(300, 180);
+        window->begin();
+        Widget *box = new Widget(20, 40, 260, 100, "Hello, World!");
+        box->box(UP_BOX);
+        box->labelfont(HELVETICA_BOLD_ITALIC);
         box->labelsize(36);
-        box->labeltype(FL_SHADOW_LABEL);
+        box->labeltype(SHADOW_LABEL);
         window->end();
         window->show(argc, argv);
-        return Fl::run();
-    }
+        return run();
+      }
 
-    my $OBJ = $CC->compile('C++'                => 1,
-                           source               => $SRC,
+    my $obj = $CC->compile('C++'                => 1,
+                           source               => $source,
                            include_dirs         => [$AF->include_dirs()],
                            extra_compiler_flags => $AF->cxxflags()
     );
-    my $EXE =
-        $CC->link_executable(objects            => $OBJ,
-                             extra_linker_flags => $AF->ldflags());
-    print system('./' . $EXE) ? 'Aww...' : 'Yay!';
-    END { unlink grep defined, $SRC, $OBJ, $EXE; }
+    my $exe = $CC->link_executable(objects            => $obj,
+                                   extra_linker_flags => $AF->ldflags());
+    print system('./' . $exe) ? 'Aww...' : 'Yay!';
+    END { unlink grep defined, $source, $obj, $exe; }
 }
 
 =pod
@@ -56,6 +59,6 @@ Creative Commons Attribution-Share Alike 3.0 License. See
 http://creativecommons.org/licenses/by-sa/3.0/us/legalcode.  For
 clarification, see http://creativecommons.org/licenses/by-sa/3.0/us/.
 
-=for git $Id: 0000_synopsis.pl 3138bae 2010-01-17 03:55:44Z sanko@cpan.org $
+=for git $Id: 0000_synopsis.pl ea85283 2010-01-17 19:42:37Z sanko@cpan.org $
 
 =cut
